Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Request ¶
type Request struct {
// contains filtered or unexported fields
}
A Request holds the arguments for an http request to the server.
func NewEmptyReq ¶
func NewEmptyReq() *Request
NewEmptyReq creates a new request that needs no arguments, and hence no validation to be used.
func NewReq ¶
NewReq creates a new request with the required arguments to be meet as a string array slice.
func (*Request) AddArgument ¶
AddArgument adds an argument to a request, guiven a pair key value.
func (*Request) AssertRequired ¶
AssertRequired asserts that the required arguments of the request are meeted, if they arent, an error describing the missings required arguments is returned.
func (*Request) GetArguments ¶
GetArguments returns a map with both keys and values as strings.
Click to show internal directories.
Click to hide internal directories.